@@ -3,16 +3,10 @@
   gcombobox.cpp
 
   (c) 2004-2006 - Daniel Campos Fernández <dcamposf@gmail.com>
-  
-  Gtkmae "GTK+ made easy" classes
-  
-  Realizado para la Junta de Extremadura. 
-  Consejería de Educación Ciencia y Tecnología. 
-  Proyecto gnuLinEx
-  
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -22,13 +16,14 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
 #include "widgets.h"
-#include "widgets_private.h"
 #include "gmainwindow.h"
+#include "gdesktop.h"
 #include "gcombobox.h"
 
 /**************************************************************************
@@ -44,15 +39,19 @@ static void cb_click(GtkComboBox *widget,gComboBox *data)
 	
 	if (!data->isReadOnly() && data->count())
 	{
-		data->lock();
 		int index = data->index();
-		const char *text = index >= 0 ? data->itemText(index) : NULL;
-		if (!text) text = "";
-		gtk_entry_set_text(GTK_ENTRY(data->entry), text);
-		data->unlock();
-		data->emit(SIGNAL(data->onChange));
+		if (index >= 0)
+		{
+			const char *text = index >= 0 ? data->itemText(index) : NULL;
+			if (!text) text = "";
+			data->lock();
+			gtk_entry_set_text(GTK_ENTRY(data->entry), text);
+			data->setIndex(index);
+			data->unlock();
+			data->emit(SIGNAL(data->onChange));
+		}
 	}
-	
+
 	if (data->index() >= 0)
 		data->emit(SIGNAL(data->onClick));
 }
@@ -101,21 +100,21 @@ static void combo_cell_text(GtkComboBox *combo, GtkCellRenderer *cell, GtkTreeMo
 		(void *)NULL);
 }
 
-static GtkWidget *_button;
+static GtkWidget *_find_button;
 
 static void cb_find_button(GtkWidget *widget, gpointer data)
 {
 	if (GTK_IS_TOGGLE_BUTTON(widget))
-		_button = widget;
+		_find_button = widget;
 	else if (GTK_IS_CONTAINER(widget))
 		gtk_container_forall(GTK_CONTAINER(widget), cb_find_button, NULL);
 }
 
 static GtkWidget *find_button(GtkWidget *combo)
 {
-	_button = NULL;
+	_find_button = NULL;
 	gtk_container_forall(GTK_CONTAINER(combo), cb_find_button, NULL);
-	return _button;
+	return _find_button;
 }
 
 char *gComboBox::indexToKey(int index)
@@ -127,58 +126,167 @@ char *gComboBox::indexToKey(int index)
 	return key;	
 }
 
+void gComboBox::create(bool readOnly)
+{
+	bool first = !border;
+	char *save = NULL;
+	GB_COLOR bg, fg;
+	GList *cells;
+
+	//fprintf(stderr, "create: %d hasFocus = %d\n", readOnly, focus );
+	
+	lock();
+	
+	if (first)
+	{
+#if GTK3
+		border = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0); //gtk_event_box_new();
+#else
+		border = gtk_alignment_new(0, 0, 1, 1); //gtk_event_box_new();
+#endif
+	}
+	else
+	{
+		save = g_strdup(text());
+		bg = background();
+		fg = foreground();
+	}
+	
+	if (widget)
+	{
+		if (cell) g_object_unref(cell);
+		cell = NULL;
+		gtk_widget_destroy(widget);
+		_button = NULL;
+	}
+	
+	if (readOnly)
+	{
+		widget = gtk_combo_box_new_with_model(GTK_TREE_MODEL(tree->store));
+		entry = NULL;
+
+		cell = gtk_cell_renderer_text_new ();
+		g_object_ref_sink(cell);
+		gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(widget), cell, true);
+
+		//gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(widget), cell, "text", 0, (void *)NULL);
+		g_object_set(cell, "ypad", 0, (void *)NULL);
+
+		gtk_cell_layout_set_cell_data_func(GTK_CELL_LAYOUT(widget), cell, (GtkCellLayoutDataFunc)combo_cell_text, (gpointer)tree, NULL);
+
+#ifdef GTK3
+		gtk_widget_set_hexpand(widget, TRUE);
+#endif
+	}
+	else
+	{
+		
+#if GTK_CHECK_VERSION(2, 24, 0)
+		widget = gtk_combo_box_new_with_model_and_entry(GTK_TREE_MODEL(tree->store));
+#else
+		widget = gtk_combo_box_entry_new_with_model(GTK_TREE_MODEL(tree->store), 0);
+#endif
+		entry = gtk_bin_get_child(GTK_BIN(widget));
+
+#ifdef GTK3
+		gtk_widget_set_hexpand(entry, TRUE);
+#endif
+
+		g_signal_handler_disconnect(widget, g_signal_handler_find(widget, G_SIGNAL_MATCH_ID, g_signal_lookup("changed", G_OBJECT_TYPE(widget)), 0, 0, 0, 0));
+		
+		cells = gtk_cell_layout_get_cells(GTK_CELL_LAYOUT(widget));
+		cell = (GtkCellRenderer *)cells->data;
+		g_list_free(cells);
+		g_object_ref(cell);
+		//gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(widget), cell, "text", 0, (void *)NULL);
+		//g_object_set(cell, "ypad", 0, (void *)NULL);
+		gtk_cell_layout_set_cell_data_func(GTK_CELL_LAYOUT(widget), cell, (GtkCellLayoutDataFunc)combo_cell_text, (gpointer)tree, NULL);
+	}
+
+#ifdef GTK3
+	gtk_combo_box_set_popup_fixed_width(GTK_COMBO_BOX(widget), true);
+#endif
+
+	if (first)
+	{
+		realize(false);
+	}
+	else
+	{
+		gtk_container_add(GTK_CONTAINER(border), widget);
+		gtk_widget_show(widget);
+		widgetSignals();
+	}
+	
+	g_signal_connect(G_OBJECT(widget), "changed", G_CALLBACK(cb_click), (gpointer)this);
+
+	if (entry)
+	{
+		initEntry();
+		setColorBase();
+		//g_signal_connect(G_OBJECT(entry), "key-press-event", G_CALLBACK(gcb_keypress), (gpointer)this);
+		//g_signal_connect(G_OBJECT(entry), "key-release-event", G_CALLBACK(gcb_keyrelease), (gpointer)this);
+		g_signal_connect(G_OBJECT(entry), "focus-in-event", G_CALLBACK(gcb_focus_in), (gpointer)this);
+		g_signal_connect(G_OBJECT(entry), "focus-out-event", G_CALLBACK(gcb_focus_out), (gpointer)this);
+	}
+	else
+	{
+		_has_input_method = FALSE;
+		setColorButton();
+	}
+	
+	updateFocusHandler();
+
+	if (!first)
+	{
+		setBackground(bg);
+		setForeground(fg);
+		updateFont();
+	}
+
+	setText(save);
+	g_free(save);
+	
+	unlock();
+}
+
 gComboBox::gComboBox(gContainer *parent) : gTextBox(parent, true)
 {
-	/*if (!_style_init)
-	{
-		gtk_rc_parse_string(
-			"style \"gambas-default-combo-box-style\" {\n"
-			"  GtkComboBox::appears-as-list = 1\n"
-			"}\n"
-			"class \"GtkComboBox\" style : gtk \"gambas-default-combo-box-style\"\n"
-			);
-		_style_init = TRUE;
-	}*/
-
 	onChange = NULL;
 	onClick = NULL;
 	onActivate = NULL;
 	
-	//_no_click = false;
+	_no_background = TRUE;
 	_last_key = 0;
 	_model_dirty = false;
+	_model_dirty_timeout = 0;
 	sort = false;
+	border = widget = NULL;
 	entry = NULL;
 	_button = NULL;
+	cell = NULL;
+	_use_wheel = true;
 	
 	g_typ = Type_gComboBox;
 	
-	tree = new gTree(NULL);
+	tree = new gTree();
 	tree->addColumn();
-	tree->setHeaders(false);
+	//tree->addColumn();
+	//tree->setHeaders(false);
 	
-	border = gtk_event_box_new();
-	widget = gtk_combo_box_new_with_model(GTK_TREE_MODEL(tree->store));
-	
-	cell = gtk_cell_renderer_text_new ();
-	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(widget), cell, true);
-	//gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(widget), cell, "text", 0, (void *)NULL);
-	g_object_set(cell, "ypad", 0, (void *)NULL);
-	gtk_cell_layout_set_cell_data_func(GTK_CELL_LAYOUT(widget), cell, (GtkCellLayoutDataFunc)combo_cell_text, (gpointer)tree, NULL);
-	
-	realize(false);
-	
-	g_signal_connect(G_OBJECT(widget), "changed", G_CALLBACK(cb_click), (gpointer)this);
-
-	//button = ((_GtkComboBoxPrivate *)GTK_COMBO_BOX(widget)->priv)->arrow->parent;
-	updateFocusHandler();
-	setReadOnly(false);
+	create(false);
 }
 
 gComboBox::~gComboBox()
 {
-	gt_object_unref_sink(cell);
-	g_object_unref(G_OBJECT(tree->store));
+	if (_model_dirty_timeout)
+		g_source_remove(_model_dirty_timeout);
+	
+	 gtk_combo_box_popdown(GTK_COMBO_BOX(widget));
+	
+	if (cell) g_object_unref(cell);
+	
+	delete tree;
 }
 
 void gComboBox::popup()
@@ -186,13 +294,20 @@ void gComboBox::popup()
 	gtk_combo_box_popup(GTK_COMBO_BOX(widget));
 }
 
+#ifdef GTK3
+GtkWidget *gComboBox::getStyleSheetWidget()
+{
+	return entry ? entry : border;
+}
+
+#else
 void gComboBox::setRealBackground(gColor color)
 {
 	gControl::setRealBackground(color);
 	if (entry) 
 		set_gdk_base_color(entry, color);
 }
-
+#endif
 
 void gComboBox::setRealForeground(gColor color)
 {
@@ -212,7 +327,7 @@ int gComboBox::index()
 	return gtk_combo_box_get_active (GTK_COMBO_BOX(widget));
 }
 
-char *gComboBox::itemText(int ind)
+char* gComboBox::itemText(int ind)
 {
 	gTreeRow *row;
 	gTreeCell *cell;
@@ -263,11 +378,13 @@ char* gComboBox::text()
 
 void gComboBox::setIndex(int vl)
 {
+	//fprintf(stderr, "setIndex: %d\n", vl);
+	
 	if (vl < 0)
 		vl = -1;
 	else if (vl >= count()) 
 		return;
-	
+		
 	if (vl == index())
 	{
 		emit(SIGNAL(onClick));
@@ -276,6 +393,9 @@ void gComboBox::setIndex(int vl)
 	
 	updateModel();
 	gtk_combo_box_set_active(GTK_COMBO_BOX(widget), vl);
+
+	if (entry)
+		gTextBox::setText(itemText(vl));
 }
 
 void gComboBox::checkIndex()
@@ -301,7 +421,6 @@ void gComboBox::setItemText(int ind, const char *text)
 	cell = row->get(0);
 	if (!cell) return;
 	
-	//fprintf(stderr, "setItemText: %d %s\n", ind, text);
 	cell->setText(text);
 	
 	updateSort();
@@ -311,47 +430,7 @@ void gComboBox::setReadOnly(bool vl)
 {
 	if (isReadOnly() == vl)
 		return;
-	
-	if ((!vl) && (!entry) )
-	{		
-		entry = gtk_entry_new ();
-		/* this flag is a hack to tell the entry to fill its allocation. */
-		GTK_ENTRY(entry)->is_cell_renderer = TRUE;
-		gtk_container_add(GTK_CONTAINER(widget), entry);
-		//gtk_widget_set_size_request(entry, width(), height());
-		gtk_widget_show(entry);
-
-		if (count())
-			gTextBox::setText(itemText(index()));
-		
-		setBackground(background());
-		setForeground(foreground());
-		setFont(font());
-		
-		initEntry();
-		//g_signal_connect(G_OBJECT(entry), "key-press-event", G_CALLBACK(gcb_keypress), (gpointer)this);
-		//g_signal_connect(G_OBJECT(entry), "key-release-event", G_CALLBACK(gcb_keyrelease), (gpointer)this);
-		g_signal_connect(G_OBJECT(entry), "focus-in-event", G_CALLBACK(gcb_focus_in), (gpointer)this);
-		g_signal_connect(G_OBJECT(entry), "focus-out-event", G_CALLBACK(gcb_focus_out), (gpointer)this);
-	}
-	
-	if (vl && entry) 
-	{
-		char *txt = g_strdup(text());
-		
-		setIndex(-1);
-		gtk_widget_destroy(entry);
-		entry = NULL;
-		_button = NULL;
-		
-		_model_dirty = true;
-		updateModel();
-		
-		setText(txt);
-		g_free(txt);
-	}
-	
-	updateFocusHandler();
+	create(!isReadOnly());
 }
 
 void gComboBox::setSorted(bool vl)
@@ -363,31 +442,36 @@ void gComboBox::setText(const char *vl)
 {
 	int index = find(vl);
 	
-	if (index >= 0)
+	if (!entry || index >= 0)
 		setIndex(index);
-	else
-	{
-		setIndex(-1);
-		if (entry)
-			gTextBox::setText(vl);
-	}
+	else if (entry)
+		gTextBox::setText(vl);
 }
 
 static gboolean combo_set_model_and_sort(gComboBox *combo)
 {
+	//fprintf(stderr, "combo_set_model_and_sort\n");
 	gtk_combo_box_set_model(GTK_COMBO_BOX(combo->widget), GTK_TREE_MODEL(combo->tree->store));
+
 	if (combo->isSorted())
 		combo->tree->sort();
+	
 	combo->_model_dirty = false;
+	combo->_model_dirty_timeout = 0;
+	
 	if (combo->isReadOnly())
 		combo->checkIndex();
+	
 	return FALSE;
 }
 
 void gComboBox::updateModel()
 {
 	if (_model_dirty)
+	{
+		g_source_remove(_model_dirty_timeout);
 		combo_set_model_and_sort(this);
+	}
 }
 
 void gComboBox::updateSort()
@@ -396,8 +480,9 @@ void gComboBox::updateSort()
 		return;
 		
 	_model_dirty = true;
+	_model_dirty_timeout = g_timeout_add(0, (GSourceFunc)combo_set_model_and_sort, this);
+	
 	gtk_combo_box_set_model(GTK_COMBO_BOX(widget), NULL);
-	g_timeout_add(0, (GSourceFunc)combo_set_model_and_sort, this);
 }
 
 void gComboBox::add(const char *text, int pos)
@@ -417,7 +502,9 @@ void gComboBox::add(const char *text, int pos)
 	else
 		after = indexToKey(pos);
 
-	row = tree->addRow(key, NULL, after, true);
+	//g_signal_lookup("rowGTK_TYPE_COMBO_BOX);
+
+	row = tree->addRow(key, after, true);
 	if (row) 
 	{
 		cell = row->get(0);
@@ -468,17 +555,17 @@ void gComboBox::remove(int pos)
 void gComboBox::resize(int w, int h)
 {
 	gControl::resize(w,h);
-	
-	if (entry)
-		gtk_widget_set_size_request(entry, width(), height());
 }
 
-void gComboBox::setFont(gFont *f)
+void gComboBox::updateFont()
 {
-	gControl::setFont(f);
-	g_object_set(G_OBJECT(cell), "font-desc", font() ? font()->desc() : NULL, (void *)NULL);
-	if (entry)
-		gtk_widget_modify_font(entry, font() ? font()->desc() : NULL);
+	gControl::updateFont();
+	if (cell)
+		g_object_set(G_OBJECT(cell), "font-desc", font()->desc(), (void *)NULL);
+#ifndef GTK3
+	else
+		gtk_widget_modify_font(entry, font()->desc());
+#endif
 }
 
 void gComboBox::setFocus()
@@ -490,13 +577,20 @@ void gComboBox::setFocus()
 
 int gComboBox::minimumHeight()
 {
+	int h;
+#ifdef GTK3
+	gtk_widget_get_preferred_height(widget, &h, NULL);
+#else
 	GtkRequisition req;
 	
 	gtk_widget_size_request(widget, &req);
+	h = req.height;
+#endif
+
 	if (entry)
-		return req.height - 4;
+		return h - 4;
 	else
-		return req.height;
+		return h;
 }
 
 
@@ -536,3 +630,16 @@ void gComboBox::updateFocusHandler()
 	g_signal_connect(G_OBJECT(button), "focus-in-event", G_CALLBACK(button_focus_in), (gpointer)this);
 	g_signal_connect(G_OBJECT(button), "focus-out-event", G_CALLBACK(button_focus_out), (gpointer)this);
 }
+
+bool gComboBox::hasBorder() const
+{
+	gboolean v;
+	
+	g_object_get(G_OBJECT(widget), "has-frame", &v, (void *)NULL);
+	return v;
+}
+
+void gComboBox::setBorder(bool v)
+{
+	g_object_set(G_OBJECT(widget), "has-frame", v, 	(void *)NULL);
+}
