@@ -55,6 +55,7 @@ bool gApplication::fix_oxygen = false;
 **************************************************************************/
 
 static bool _focus_change = false;
+static bool _doing_focus_change = false;
 
 static GtkWindowGroup *get_window_group(GtkWidget *widget)
 {
@@ -219,6 +220,7 @@ static void gambas_handle_event(GdkEvent *event)
 	bool cancel;
 	int type;
 	bool handle_event = false;
+	bool send_to_window = false;
 
 	if (gApplication::_fix_printer_dialog)
 	{
@@ -516,8 +518,8 @@ __FOUND_WIDGET:
 		case GDK_BUTTON_RELEASE:
 		{
 			/*if (event->type == GDK_BUTTON_PRESS)
-				fprintf(stderr, "GDK_BUTTON_PRESS: %p / %p\n", control, button_grab);
-			else if (event->type == GDK_BUTTON_RELEASE)
+				fprintf(stderr, "GDK_BUTTON_PRESS: %p / %p / %p\n", control, button_grab, gApplication::_control_grab);*/
+			/*else if (event->type == GDK_BUTTON_RELEASE)
 				fprintf(stderr, "GDK_BUTTON_RELEASE: %p / %p\n", control, button_grab);*/
 			
 			switch ((int)event->type)
@@ -528,6 +530,7 @@ __FOUND_WIDGET:
 			}
 
 			save_control = find_child(control, (int)event->button.x_root, (int)event->button.y_root, button_grab);
+			//fprintf(stderr, "save_control = %p %s\n", save_control, save_control ? save_control->name() : "");
 			
 			if (!save_control)
 			{
@@ -806,12 +809,14 @@ __FOUND_WIDGET:
 
 			if (event->key.keyval)
 				gKey::_last_key_press = event->key.keyval;
+			send_to_window = control->isWindow();
 			goto __HANDLE_EVENT;
 
 		case GDK_KEY_RELEASE:
 
 			if (event->key.keyval)
 				gKey::_last_key_release = event->key.keyval;
+			send_to_window = control->isWindow();
 			goto __HANDLE_EVENT;
 	}
 
@@ -833,6 +838,9 @@ __RETURN:
 	
 	if (handle_event)
 		gtk_main_do_event(event);
+	
+	if (send_to_window)
+		gcb_key_event(widget, event, control);
 
 	if (!gdk_events_pending()) // && event->type != GDK_ENTER_NOTIFY && event->type != GDK_LEAVE_NOTIFY)
 	{
@@ -1294,10 +1302,12 @@ static void post_focus_change(void *)
 {
 	gControl *current, *control, *next;
 
-	if (!_focus_change)
+	if (!_focus_change || _doing_focus_change)
 		return;
 
 	//fprintf(stderr, "post_focus_change\n");
+	
+	_doing_focus_change = true;
 
 	for(;;)
 	{
@@ -1333,7 +1343,8 @@ static void post_focus_change(void *)
 		}
 	}
 
-	_focus_change = FALSE;
+	_doing_focus_change = false;
+	_focus_change = false;
 }
 
 void gApplication::handleFocusNow()
@@ -1346,7 +1357,7 @@ static void handle_focus_change()
 	if (_focus_change)
 		return;
 
-	_focus_change = TRUE;
+	_focus_change = true;
 	GB.Post((void (*)())post_focus_change, (intptr_t)NULL);
 }
 
