@@ -2,13 +2,11 @@
 
   main.c
 
-  Advanced Network Component
-
   (c) 2003-2008 Daniel Campos Fernández <dcamposf@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -18,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -35,44 +34,27 @@
 
 #include "main.h"
 
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-
-
 GB_INTERFACE GB EXPORT;
 
-
-
 GB_DESC *GB_CLASSES[] EXPORT =
 {
   CNetDesc,
   CProxyDesc,
-  CCurlDesc,
-  CHttpClientDesc,
+  CurlSSLDesc,
+  CurlDesc,
+  HttpClientDesc,
   CFtpClientDesc,
   NULL
 };
 
-
-
 int EXPORT GB_INIT(void)
 {
-  curl_global_init(0);
+  curl_global_init(CURL_GLOBAL_ALL);
   return 0;
 }
 
-
-
 void EXPORT GB_EXIT()
 {
   curl_global_cleanup();
 }
 
-
-#ifdef _cpluscplus
-}
-#endif
-
