@@ -29,10 +29,21 @@
 #include <PDFDoc.h>
 #include <SplashOutputDev.h>
 #include <Page.h>
+#if POPPLER_VERSION_0_76
+#include <vector>
+#include <Outline.h>
+#else
 #include <goo/GooList.h>
+#endif
 #include <stdint.h>
 
-#if POPPLER_VERSION_0_64
+#if POPPLER_VERSION_0_76
+#define const_LinkAction const LinkAction
+#define const_LinkDest const LinkDest
+#define const_GooList const std::vector<OutlineItem*>
+#define GooList std::vector<OutlineItem*>
+#define const_GooString const GooString
+#elif POPPLER_VERSION_0_64
 #define const_LinkAction const LinkAction
 #define const_LinkDest const LinkDest
 #define const_GooList const GooList
@@ -64,6 +75,22 @@ extern GB_DESC PdfModeDesc[];
 
 #endif
 
+#if POPPLER_VERSION_0_76
+
+#define CPDF_list_get(_list, _i) ((_list)->at(_i))
+#define CPDF_list_count(_list) ((_list)->size())
+
+#else
+
+#define CPDF_list_get(_list, _i) ((OutlineItem *)(_list)->get(_i))
+#define CPDF_list_count(_list) ((_list)->getLength())
+
+#endif
+
+#define CPDF_index_get(_i) CPDF_list_get(THIS->index, _i)
+#define CPDF_index_count() CPDF_list_count(THIS->index)
+
+
 typedef
 	struct {
 		GB_BASE ob;
