@@ -1,14 +1,12 @@
 /***************************************************************************
 
-  error.h
+  gb_error.h
 
-  Error management
-
-  (c) 2000-2007 Benoit Minisini <gambas@users.sourceforge.net>
+  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -18,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -30,12 +29,16 @@
 
 #include "gb_limit.h"
 
-#define E_UNKNOWN     ((const char *)0)
-#define E_MEMORY      ((const char *)1)
-#define E_OPEN        ((const char *)2)
-#define E_READ        ((const char *)3)
-#define E_SYNTAX      ((const char *)4)
-#define E_UNEXPECTED  ((const char *)5)
+#define E_UNKNOWN            ((const char *)0)
+#define E_MEMORY             ((const char *)1)
+#define E_OPEN               ((const char *)2)
+#define E_READ               ((const char *)3)
+#define E_SYNTAX             ((const char *)4)
+#define E_UNEXPECTED         ((const char *)5)
+#define E_EXPECTED           ((const char *)6)
+#define E_MISSING            ((const char *)7)
+#define E_SYNTAX_MISSING     ((const char *)8)
+#define E_TOOLONG            ((const char *)9)
 
 typedef
   struct {
@@ -54,6 +57,8 @@ typedef
 
 #ifndef __GB_ERROR_C
 EXTERN ERROR_INFO ERROR_info;
+EXTERN bool ERROR_translate;
+EXTERN ERROR_CONTEXT *ERROR_current;
 #endif
 
 
@@ -71,10 +76,10 @@ EXTERN ERROR_INFO ERROR_info;
 #define FINALLY
 
 #define CATCH \
-			if (__err->code != 0 && !(__err->code = 0))
+			if (__err->code != 0 && ((__err->code = 0), TRUE))
 
 #define CATCH_GET(get_it) \
-     	if (__err->code != 0 && (get_it = __err->code) && !(__err->code = 0))
+     	if (__err->code != 0 && ((get_it = __err->code), TRUE) && ((__err->code = 0), TRUE))
 
 #define END_TRY \
 			if (__err->code == 0) \
@@ -84,23 +89,38 @@ EXTERN ERROR_INFO ERROR_info;
   	} \
 	}
 
+#define ERROR_enter(_err) \
+do { \
+  _err->prev = ERROR_current; \
+  _err->code = 0; \
+  ERROR_current = _err; \
+} while(0)
+
+#define ERROR_leave(_err) \
+do { \
+  if (_err->prev != ERROR_LEAVE_DONE) \
+	{ \
+		ERROR_CONTEXT *_prev = _err->prev; \
+		_err->prev = ERROR_LEAVE_DONE; \
+		ERROR_current = _prev; \
+	} \
+} while(0)
+
 #define ERROR_clear() (ERROR_info.code = 0)
 
-PUBLIC char *ERROR_get(void);
+char *ERROR_get(void);
 
-PUBLIC void ERROR_enter(ERROR_CONTEXT *err);
-PUBLIC void ERROR_leave(ERROR_CONTEXT *err);
+void ERROR_define(const char *pattern, const char *arg[]);
 
-PUBLIC void ERROR_define(const char *pattern, const char *arg[]);
+void PROPAGATE() NORETURN;
+void THROW(const char *code, ...) NORETURN;
+void THROW_SYSTEM(int err, const char *path);
 
-PUBLIC void PROPAGATE() NORETURN;
-PUBLIC void THROW(const char *code, ...) NORETURN;
-PUBLIC void THROW_SYSTEM(int err, const char *path);
+void ERROR_panic(const char *error, ...) NORETURN;
 
-PUBLIC void ERROR_panic(const char *error, ...) NORETURN;
-
-PUBLIC void ERROR_print(void);
-PUBLIC void ERROR_print_at(FILE *where);
+void ERROR_print(void);
+void ERROR_print_at(FILE *where);
+void ERROR_warning(const char *warning, ...);
 
 /*PUBLIC void ERROR_must_free(void *object);*/
 
