@@ -43,6 +43,14 @@ enum {
 	MSG_WARNING = 1
 };
 
+enum {
+	JOB_STEP_NONE = 0,
+	JOB_STEP_READ = 1,
+	JOB_STEP_CODE = 2,
+	JOB_STEP_TREE = 3,
+	JOB_STEP_OUTPUT = 4
+};
+
 typedef
 	struct {
 		char *name;                        // source file name
@@ -50,6 +58,7 @@ typedef
 		int first_line;                    // first line to compile
 		int max_line;                      // maximum line number
 		char *source;                      // source file contents
+		unsigned step : 3;                 // compiler step (JOB_STEP_*)
 		unsigned verbose : 1;              // verbose compilation
 		unsigned debug : 1;                // if debugging information must be generated
 		unsigned trans : 1;                // if translation files must be generated
@@ -63,13 +72,13 @@ typedef
 		unsigned public_module : 1;        // modules symbols are public by default
 		unsigned trans_error : 1;          // display error messages in a translatable form
 		unsigned no_old_read_syntax : 1;   // do not compile the old read syntax
-		unsigned column : 1;               // search column where there is an error
 		unsigned exec : 1;                 // we are compiling for an executable
 		unsigned warnings : 1;             // if warnings must be printed
-		unsigned _reserved : 16;           // reserved
+		unsigned _reserved : 14;           // reserved
 		char *output;                      // output file
 		PATTERN *pattern;                  // lexical analyze
 		int pattern_count;                 // number of patterns
+		int *pattern_pos;                  // position of a pattern in its line
 		PATTERN *current;                  // current pattern
 		PATTERN *end;                      // last pattern
 		FUNCTION *func;                    // current function being compiled
@@ -81,6 +90,7 @@ typedef
 		const char **help;                 // help comments array
 		int help_first_line;               // line of the first help comment
 		char *hname;                       // help file name
+		PATTERN *column;                   // where to search the current column
 		}
 	COMPILE;
 
@@ -109,4 +119,6 @@ void COMPILE_end_class(void);
 void COMPILE_enum_class(char **name, int *len);
 void COMPILE_print(int type, int line, const char *msg, ...);
 
+#define COMPILE_get_column(_pattern) (JOB->pattern_pos[(_pattern) - JOB->pattern])
+
 #endif
