@@ -290,10 +290,10 @@ static int sort_symbol(const int *a, const int *b)
 static void add_class(const char *name, bool has_static)
 {
 	int index;
-
+	
 	if (out_list)
 	{
-		if (!TABLE_add_symbol(_classes, name, strlen(name), &index))
+		if (!TABLE_add_symbol_exist(_classes, name, strlen(name), &index))
 		{
 			fputs(name, out_list);
 			if (has_static)
