@@ -1,14 +1,12 @@
 /***************************************************************************
 
-  CClass.h
+  gbx_c_class.h
 
-  The native class Class needed for introspection
-
-  (c) 2000-2005 Benoît Minisini <gambas@users.sourceforge.net>
+  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -18,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -28,17 +27,12 @@
 #include "gambas.h"
 
 #ifndef __GBX_C_CLASS_C
-
-EXTERN GB_DESC NATIVE_ClassSymbols[];
-EXTERN GB_DESC NATIVE_Component[];
-EXTERN GB_DESC NATIVE_Components[];
-EXTERN GB_DESC NATIVE_Class[];
-EXTERN GB_DESC NATIVE_Classes[];
-EXTERN GB_DESC NATIVE_Object[];
-EXTERN GB_DESC NATIVE_Symbol[];
-
+extern GB_DESC NATIVE_Component[];
+extern GB_DESC NATIVE_Components[];
+extern GB_DESC NATIVE_Class[];
+extern GB_DESC NATIVE_Classes[];
+extern GB_DESC NATIVE_Object[];
+extern GB_DESC NATIVE_Symbol[];
 #endif
 
-#define SYMBOL_TO_CDS(object)  ((CLASS_DESC_SYMBOL *)((char *)object - (long)&(((CLASS_DESC_SYMBOL *)0)->ref)))
-
 #endif
