@@ -1,14 +1,12 @@
 /***************************************************************************
 
-  library.h
+  gbx_library.h
 
-  GAMBAS plug-in management routines
-
-  (c) 2000-2007 Benoit Minisini <gambas@users.sourceforge.net>
+  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -18,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -50,28 +49,29 @@ typedef
     void (*signal)();
     int (*info)();
     unsigned persistent : 1;
-    unsigned _reserved: 31;
+    unsigned _reserved: 13;
     }
-  PACKED
   LIBRARY;
 
 #ifndef __GBX_LIBRARY_C
 #endif
 
-void LIBRARY_preload(const char *file, char **argv);
-
 void LIBRARY_init(void);
 void LIBRARY_exit(void);
 
 LIBRARY *LIBRARY_create(const char *path);
 void LIBRARY_delete(LIBRARY *lib);
 
-void LIBRARY_load(LIBRARY *lib);
+int LIBRARY_load(LIBRARY *lib);
 void LIBRARY_unload(LIBRARY *lib);
 
 void LIBRARY_declare(GB_DESC **desc);
+void LIBRARY_declare_one(GB_DESC *desc);
 
-boolean LIBRARY_get_interface_by_name(const char *name, int version, void *iface);
+bool LIBRARY_get_interface_by_name(const char *name, int version, void *iface);
 void LIBRARY_get_interface(LIBRARY *lib, int version, void *iface);
 
+void LIBRARY_exec(LIBRARY *lib, int argc, char **argv);
+void LIBRARY_after_init(LIBRARY *lib);
+
 #endif
