@@ -57,11 +57,8 @@
 //#define DEBUG_LANG
 
 #define buffer_init COMMON_buffer_init
-#define get_char COMMON_get_char
-#define last_char COMMON_last_char
 #define look_char COMMON_look_char
 #define put_char COMMON_put_char
-#define jump_space COMMON_jump_space
 #define get_current COMMON_get_current
 #define buffer_pos COMMON_pos
 #define get_size_left COMMON_get_size_left
@@ -265,32 +262,6 @@ static void add_zero(int count, int *before)
 }
 
 
-static int search(const char *src, int len, const char *list, int start, bool not)
-{
-	int i;
-	char c;
-
-	for (i = start; i < len; i++)
-	{
-		c = src[i];
-		
-		if (c == '\\')
-		{
-			i++;
-			if (i >= len)
-				break;
-			c = src[i];
-			continue;
-		}
-
-		if ((index(list, c) != NULL) ^ not)
-			return i;
-	}
-
-	return len;
-}
-
-
 static void add_sign(char mode, int sign, bool after)
 {
 	if (after && mode != '(')
@@ -318,8 +289,11 @@ static char *get_languages(void)
 	char *lang;
 	char *lang_list = NULL;
 	char *src;
+	char *p;
 
 	lang = STRING_new_temp_zero(LOCAL_get_lang());
+	p = index(lang, '.');
+	if (p) *p = 0;
 
 	lang_list = STRING_add(lang_list, lang, 0);
 	lang_list = STRING_add_char(lang_list, ':');
@@ -332,6 +306,9 @@ static char *get_languages(void)
 		lang_list = STRING_add_char(lang_list, ':');
 	}
 
+	lang_list = STRING_add(lang_list, lang, 0);
+	lang_list = STRING_add(lang_list, "_*", 2);
+
 	#ifdef DEBUG_LANG
 	fprintf(stderr, "Languages = %s\n", lang_list);
 	#endif
@@ -566,11 +543,11 @@ static void fill_local_info(void)
 	LOCAL_local.currency_symbol = info->currency_symbol;
 	LOCAL_local.intl_currency_symbol = info->int_curr_symbol;
 
-	strcpy(LOCAL_local.general_currency, "($#,##0.");
+	strcpy(LOCAL_local.general_currency, "($,0.");
 	strncat(LOCAL_local.general_currency, "########", Min(8, info->frac_digits));
 	strcat(LOCAL_local.general_currency, ")");
 
-	strcpy(LOCAL_local.intl_currency, "($$#,##0.");
+	strcpy(LOCAL_local.intl_currency, "($$,0.");
 	strncat(LOCAL_local.intl_currency, "########", Min(8, info->int_frac_digits));
 	strcat(LOCAL_local.intl_currency, ")");
 
@@ -628,7 +605,6 @@ void LOCAL_set_lang(const char *lang)
 	char **l;
 	int rtl;
 	char *var;
-	char *err;
 
 	if (lang && (strlen(lang) > MAX_LANG))
 		THROW(E_ARG);
@@ -648,7 +624,7 @@ void LOCAL_set_lang(const char *lang)
 
 	if (getenv("LANGUAGE"))
 		my_setenv("LANGUAGE", lang, env_LANGUAGE);
-		
+	
 	if (setlocale(LC_ALL, ""))
 	{
 		_translation_loaded = FALSE;
@@ -656,7 +632,7 @@ void LOCAL_set_lang(const char *lang)
 	}
 	else
 	{
-		err = strerror(errno);
+		char *err = strerror(errno);
 		ERROR_warning("cannot switch to language '%s': %s. Did you install the corresponding locale packages?", lang ? lang : LOCAL_get_lang(), err);
 		setlocale(LC_ALL, "C");
 	}
@@ -684,27 +660,71 @@ void LOCAL_set_lang(const char *lang)
 	LOCAL_local.rtl = rtl;
 }
 
+
+static int int_to_string(uint64_t nbr, char **addr)
+{
+	static char buf[32];
+	char *ptr;
+	int digit, len;
+	bool neg;
+
+	len = 0;
+	ptr = &buf[sizeof(buf)];
+
+	if (nbr == 0)
+	{
+		ptr -= 2;
+		*addr = ptr;
+		ptr[0] = '0';
+		ptr[1] = 0;
+		return 1;
+	}
+	
+	neg = (nbr & (1LL << 63)) != 0;
+	
+	if (neg)
+		nbr = 1 + ~nbr;
+	
+	while (nbr > 0)
+	{
+		digit = nbr % 10;
+		nbr /= 10;
+
+		ptr--;
+		len++;
+
+		*ptr = '0' + digit;
+	}
+
+	if (neg)
+	{
+		len++;
+		ptr--;
+		*ptr = '-';
+	}
+	
+	*addr = ptr;
+	return len;
+}
+
+
 bool LOCAL_format_number(double number, int fmt_type, const char *fmt, int len_fmt, char **str, int *len_str, bool local)
 {
-	char c;
+	int i;
+	unsigned char c;
 	int n;
-
-	char buf[32];
-	char *buf_start;
-
+	char *buf_addr;
 	int pos;
-	//int pos2;
 	int thousand;
 	int *thousand_ptr;
-
 	char sign;
 	bool comma;
 	bool point;
 	int before, before_zero;
 	int after, after_zero;
-	char exposant;
-	//char exp_sign;
+	char exponent;
 	int exp_zero;
+	bool exp_sign;
 
 	int number_sign;
 	uint64_t mantisse;
@@ -751,7 +771,7 @@ bool LOCAL_format_number(double number, int fmt_type, const char *fmt, int len_f
 			break;
 
 		case LF_SCIENTIFIC:
-			fmt = "0.################E+#";
+			fmt = "0.################E+0";
 			break;
 
 		case LF_CURRENCY:
@@ -772,49 +792,6 @@ bool LOCAL_format_number(double number, int fmt_type, const char *fmt, int len_f
 	if (len_fmt >= COMMON_BUF_MAX)
 		return TRUE;
 
-	// Remove, not documented!
-	
-#if 0
-	/* looking for negative and null numbers formats */
-
-	pos = search(fmt, len_fmt, ";", 0, FALSE);
-
-	if (number <= 0.0)
-	{
-		if (pos < len_fmt)
-		{
-			if (number < 0.0)
-			{
-				if ((pos < (len_fmt - 1)) && fmt[pos + 1] != ';')
-				{
-					fmt = &fmt[pos + 1];
-					len_fmt -= pos + 1;
-				}
-				else
-					len_fmt = pos;
-			}
-			else
-			{
-				pos2 = search(fmt, len_fmt, ";", pos + 1, FALSE);
-				if (pos2 < len_fmt)
-				{
-					if ((pos2 < (len_fmt - 1)) && fmt[pos2 + 1] != ';')
-					{
-						fmt = &fmt[pos2 + 1];
-						len_fmt -= pos2 + 1;
-					}
-					else
-						len_fmt = pos;
-				}
-			}
-		}
-	}
-	else if (pos < len_fmt)
-		len_fmt = pos;
-#endif
-
-	/* translate Gambas format to sprintf format */
-
 	sign = 0;
 	comma = FALSE;
 	before = 0;
@@ -822,30 +799,54 @@ bool LOCAL_format_number(double number, int fmt_type, const char *fmt, int len_f
 	point = FALSE;
 	after = 0;
 	after_zero = 0;
-	exposant = 0;
-	//exp_sign = 0;
+	exponent = 0;
+	exp_sign = FALSE;
 	exp_zero = 0;
 	_currency = FALSE;
 	intl_currency = FALSE;
 
 	begin();
 
-	/* Looking for '%' */
-
-	pos = search(fmt, len_fmt, "%", 0, FALSE);
-	if (pos < len_fmt)
-		number *= 100;
-
-	/* format prefix */
-
-	pos = search(fmt, len_fmt, "-+#0.,($", 0, FALSE);
-
-	if (pos >= len_fmt)
+	// Search for the first formatting character
+	
+	for (i = 0; i < len_fmt; i++)
+	{
+		c = fmt[i];
+		if (c == '\\')
+		{
+			i++;
+			continue;
+		}
+		
+		if (c == '-' || c == '+' || c == '#' || c == '0' || c == '.' || c == ',' || c == '(' || c == '$')
+			break;
+	}
+	
+	if (i >= len_fmt)
 		return TRUE;
 
+	pos = i;
 	if (pos > 0)
 		add_string(fmt, pos, NULL);
 
+	// Search if there is a percent format character
+	
+	for (i = pos; i < len_fmt; i++)
+	{
+		c = fmt[i];
+		if (c == '\\')
+		{
+			i++;
+			continue;
+		}
+		
+		if (c == '%')
+		{
+			number *= 100;
+			break;
+		}
+	}
+	
 	/* specify the sign */
 
 	if (fmt[pos] == '-')
@@ -942,20 +943,15 @@ bool LOCAL_format_number(double number, int fmt_type, const char *fmt, int len_f
 
 	if (fmt[pos] == 'e' || fmt[pos] == 'E')
 	{
-		exposant = fmt[pos];
-		//exp_sign = ' ';
+		exponent = fmt[pos];
 
 		pos++;
 		if (pos >= len_fmt)
 			return TRUE;
 
-		if (fmt[pos] == '-')
+		if (fmt[pos] == '-' || fmt[pos] == '+')
 		{
-			pos++;
-		}
-		else if (fmt[pos] == '+')
-		{
-			//exp_sign = '+';
+			exp_sign = TRUE;
 			pos++;
 		}
 
@@ -1008,7 +1004,7 @@ _FORMAT:
 		number_mant = frexp10(fabs(number), &number_exp);
 		ndigit = after;
 		
-		if (!exposant) 
+		if (!exponent) 
 			ndigit += number_exp;
 		else
 			ndigit++;
@@ -1026,33 +1022,37 @@ _FORMAT:
 
 		if (mantisse >= power)
 		{
-			ndigit = sprintf(buf, ".%" PRId64, mantisse);
-			buf[0] = buf[1];
-			buf[1] = '.';
+			ndigit = int_to_string(mantisse, &buf_addr);
+			buf_addr--;
+			buf_addr[0] = buf_addr[1];
+			buf_addr[1] = '.';
+			ndigit++;
 		}
 		else
 		{
-			ndigit = sprintf(buf, "0.%" PRId64, mantisse);
+			ndigit = int_to_string(mantisse, &buf_addr);
+			buf_addr -= 2;
+			buf_addr[0] = '0';
+			buf_addr[1] = '.';
+			ndigit += 2;
 		}
 
 		ndigit--;
-		buf[ndigit] = 0;
+		buf_addr[ndigit] = 0;
 
 		/* 0.0 <= number_mant < 1.0 */
 
 		//number_exp++; /* simplifie les choses */
 
 		number_real_exp = number_exp;
-		if (exposant)
+		if (exponent)
 			number_exp = number != 0.0;
 
 		// should return "0[.]...", or "1[.]..." if the number is rounded up.
 
-		buf_start = buf;
-
-		if (buf_start[0] == '1') // the number has been rounded up.
+		if (buf_addr[0] == '1') // the number has been rounded up.
 		{
-			if (exposant)
+			if (exponent)
 				number_real_exp++;
 			else
 				number_exp++;
@@ -1060,19 +1060,19 @@ _FORMAT:
 
 		if (ndigit > 1) // so there is a point
 		{
-			if (buf_start[0] == '0')
+			if (buf_addr[0] == '0')
 			{
-				buf_start += 2;
+				buf_addr += 2;
 				ndigit -= 2;
 			}
 			else
 			{
-				buf_start[1] = buf_start[0];
+				buf_addr[1] = buf_addr[0];
 				ndigit--;
-				buf_start++;
+				buf_addr++;
 			}
 
-			while (ndigit > 0 && buf_start[ndigit - 1] == '0')
+			while (ndigit > 0 && buf_addr[ndigit - 1] == '0')
 				ndigit--;
 		}
 
@@ -1086,7 +1086,7 @@ _FORMAT:
 			add_char(' ', before - Max(before_zero, number_exp), thousand_ptr);
 			add_zero(before_zero - number_exp, thousand_ptr);
 
-			add_string(buf_start, Min(number_exp, ndigit), thousand_ptr);
+			add_string(buf_addr, Min(number_exp, ndigit), thousand_ptr);
 
 			if (number_exp > ndigit)
 				add_zero(number_exp - ndigit, thousand_ptr);
@@ -1124,14 +1124,14 @@ _FORMAT:
 
 			if (number_exp > 0)
 			{
-				buf_start += number_exp;
+				buf_addr += number_exp;
 				ndigit -= number_exp;
 			}
 
 			n = Min(ndigit, after);
 			if (n > 0)
 			{
-				add_string(buf_start, n, NULL);
+				add_string(buf_addr, n, NULL);
 				after -= n;
 				after_zero -= n;
 			}
@@ -1150,13 +1150,20 @@ _FORMAT:
 		if (look_char() != local_current->decimal_point)
 			buffer_pos++;
 
-		/* exponant */
+		/* exponent */
 
-		if (exposant != 0) // && number != 0.0)
+		if (exponent != 0) // && number != 0.0)
 		{
-			put_char(exposant);
-			n = snprintf(buf, sizeof(buf), "%+.*d", exp_zero, number_real_exp - 1);
-			add_string(buf, n, NULL);
+			put_char(exponent);
+			if (exp_sign && number_real_exp >= 1)
+				put_char('+');
+			n = int_to_string(number_real_exp - 1, &buf_addr);
+			while (exp_zero > n)
+			{
+				put_char('0');
+				exp_zero--;
+			}
+			add_string(buf_addr, n, NULL);
 		}
 	}
 	else // isfinite
@@ -1520,11 +1527,13 @@ static void LOCAL_load_translation(ARCHIVE *arch)
 	char *src;
 	char *test;
 	char c;
-	const char *dst = NULL;
 	FILE *file;
 	char *addr;
 	int len;
 	COMPONENT *save = COMPONENT_current;
+	char *path;
+	const char *dir;
+	char *dst;
 
 	/* We must force GB_LoadFile() to look in our archive, because all translation
 		files of one language have the same path!
@@ -1554,7 +1563,7 @@ static void LOCAL_load_translation(ARCHIVE *arch)
 
 		if (*lang)
 		{
-			test = STRING_new_temp_zero(lang);
+			test = STRING_new_zero(lang);
 			src = test;
 
 			for(;;)
@@ -1565,8 +1574,23 @@ static void LOCAL_load_translation(ARCHIVE *arch)
 				*src = tolower(c);
 				src++;
 			}
+
+			test = STRING_add(test, ".mo", 3);
+
+			dir = arch ? ".lang" : ".../.lang";
 			
-			if (!arch)
+			FILE_dir_first(dir, test, 0);
+			STRING_free_real(test);
+			
+			if (!FILE_dir_next(&path, &len))
+			{
+				dst = STRING_new_zero(dir);
+				dst = STRING_add_char(dst, '/');
+				dst = STRING_add(dst, path, len);
+				break;
+			}
+			
+			/*if (!arch)
 				dst = FILE_cat("...", ".lang", test, NULL);
 			else
 				dst = FILE_cat(".lang", test, NULL);
@@ -1578,7 +1602,7 @@ static void LOCAL_load_translation(ARCHIVE *arch)
 			#endif
 
 			if (FILE_exist(dst))
-				break;
+				break;*/
 		}
 
 		lang = strtok(NULL, ":");
@@ -1596,6 +1620,7 @@ static void LOCAL_load_translation(ARCHIVE *arch)
 	fprintf(stderr, "Loading %s\n", dst);
 	#endif
 
+	STRING_free_later(dst);
 	if (GB_LoadFile(dst, 0, &addr, &len))
 	{
 		#ifdef DEBUG_LANG
@@ -1607,27 +1632,27 @@ static void LOCAL_load_translation(ARCHIVE *arch)
 	// These temporary files have predictable names because they
 	// are *.mo files read by the gettext system.
 
-	dst = FILE_cat(FILE_make_temp(NULL, NULL), "tr", NULL);
-	mkdir(dst, S_IRWXU);
+	dir = FILE_cat(FILE_make_temp(NULL, NULL), "tr", NULL);
+	mkdir(dir, S_IRWXU);
 
-	dst = FILE_cat(FILE_make_temp(NULL, NULL), "tr", lang, NULL);
-	mkdir(dst, S_IRWXU);
+	dir = FILE_cat(FILE_make_temp(NULL, NULL), "tr", setlocale(LC_ALL, NULL), NULL);
+	mkdir(dir, S_IRWXU);
 
-	dst = FILE_cat(dst, "LC_MESSAGES", NULL);
-	mkdir(dst, S_IRWXU);
+	dir = FILE_cat(dir, "LC_MESSAGES", NULL);
+	mkdir(dir, S_IRWXU);
 
-	dst = FILE_cat(dst, domain, NULL);
-	strcat((char *)dst, ".mo");
+	dir = FILE_cat(dir, domain, NULL);
+	strcat((char *)dir, ".mo");
 
-	unlink(dst);
+	unlink(dir);
 
 	#ifdef DEBUG_LANG
-	fprintf(stderr, "Writing to %s (%d bytes)\n", dst, len);
+	fprintf(stderr, "Writing to %s (%d bytes)\n", dir, len);
 	#endif
 
 	// No need to test previous system calls as the failure will be detected now
 
-	file = fopen(dst, "w");
+	file = fopen(dir, "w");
 	if (file)
 	{
 		fwrite(addr, len, 1, file);
@@ -1739,4 +1764,3 @@ void LOCAL_set_first_day_of_week(char day)
 	if (day >= -1 && day <= 6)
 		LOCAL_first_day_of_week = day;
 }
-
