@@ -2,11 +2,11 @@
 
   CDatabase.c
 
-  (c) 2000-2007 Benoit Minisini <gambas@users.sourceforge.net>
+  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -16,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -64,10 +65,10 @@ void *CDATABASE_get(CCONNECTION *conn, const char *name)
   if (check_database(conn, name, TRUE))
     return NULL;
 
-  GB.New(POINTER(&_object), GB.FindClass("Database"), NULL, NULL);
+  _object = GB.New(GB.FindClass("Database"), NULL, NULL);
   THIS->conn = conn;
   THIS->driver = conn->driver;
-  GB.NewString(&THIS->name, name, 0);
+  THIS->name = GB.NewZeroString(name);
   return THIS;
 }
 
@@ -96,7 +97,7 @@ void CDATABASE_release(CCONNECTION *conn, void *_object)
 BEGIN_METHOD_VOID(CDATABASE_free)
 
   if (!valid_database(THIS))
-    GB.SubCollection.Remove(THIS->conn->databases, THIS->name, 0);
+    GB_SubCollectionRemove(THIS->conn->databases, THIS->name, 0);
   GB.FreeString(&THIS->name);
 
 END_METHOD
@@ -153,19 +154,19 @@ GB_DESC CDatabaseDesc[] =
 
 /***************************************************************************
 
-  .ConnectionDatabases
+  .Connection.Databases
 
 ***************************************************************************/
 
 #undef THIS
-#define THIS ((GB_SUBCOLLECTION)_object)
+#define THIS ((CSUBCOLLECTION *)_object)
 
 BEGIN_METHOD(CDATABASE_add, GB_STRING name)
 
-  CCONNECTION *conn = GB.SubCollection.Container(THIS);
+  CCONNECTION *conn = GB_SubCollectionContainer(THIS);
   char *name = GB.ToZeroString(ARG(name));
 
-  if (DB_CheckName(name, "database"))
+  if (DB_CheckNameWith(name, "database", conn->db.db_name_char))
     return;
 
   if (check_database(conn, name, FALSE))
@@ -178,13 +179,14 @@ END_METHOD
 
 BEGIN_METHOD(CDATABASE_remove, GB_STRING name)
 
-  CCONNECTION *conn = GB.SubCollection.Container(THIS);
+  CCONNECTION *conn = GB_SubCollectionContainer(THIS);
   char *name = GB.ToZeroString(ARG(name));
 
+  GB_SubCollectionRemove(THIS, STRING(name), LENGTH(name));
+	
   if (check_database(conn, name, TRUE))
     return;
 
-  GB.SubCollection.Remove(THIS, STRING(name), LENGTH(name));
   conn->driver->Database.Delete(&conn->db, name);
 
 END_METHOD
@@ -193,7 +195,7 @@ END_METHOD
 
 GB_DESC CConnectionDatabasesDesc[] =
 {
-  GB_DECLARE(".ConnectionDatabases", 0), GB_INHERITS(".SubCollection"),
+  GB_DECLARE(".Connection.Databases", 0), GB_INHERITS(".SubCollection"),
 
   GB_METHOD("Add", NULL, CDATABASE_add, "(Name)s"),
   GB_METHOD("Remove", NULL, CDATABASE_remove, "(Name)s"),
