@@ -2,11 +2,11 @@
 
   CResultField.h
 
-  (c) 2000-2007 Benoit Minisini <gambas@users.sourceforge.net>
+  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -16,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -50,7 +51,7 @@ int CRESULTFIELD_exist(CRESULT *result, const char *name);
 int CRESULTFIELD_find(CRESULT *result, const char *name, bool error);
 void CRESULTFIELD_release(CRESULT *result, void *_object);
 
-char *CRESULTFIELD_key(CRESULT *result, long index);
+char *CRESULTFIELD_key(CRESULT *result, int index);
 
 #endif
 
