@@ -2,11 +2,11 @@
 
   CUser.c
 
-  (c) 2000-2007 Benoit Minisini <gambas@users.sourceforge.net>
+  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -16,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -64,10 +65,10 @@ void *CUSER_get(CCONNECTION *conn, const char *name)
   if (check_user(conn, name, TRUE))
     return NULL;
 
-  GB.New(POINTER(&_object), GB.FindClass("DatabaseUser"), NULL, NULL);
+  _object = GB.New(GB.FindClass("DatabaseUser"), NULL, NULL);
   THIS->conn = conn;
   THIS->driver = conn->driver;
-  GB.NewString(&THIS->name, name, 0);
+  THIS->name = GB.NewZeroString(name);
   conn->driver->User.Info(&conn->db, THIS->name, &THIS->info);
   return THIS;
 }
@@ -100,7 +101,7 @@ void CUSER_release(CCONNECTION *conn, void *_object)
 BEGIN_METHOD_VOID(CUSER_free)
 
   if (!valid_user(THIS))
-    GB.SubCollection.Remove(THIS->conn->users, THIS->name, 0);
+    GB_SubCollectionRemove(THIS->conn->users, THIS->name, 0);
   GB.FreeString(&THIS->name);
   GB.FreeString(&THIS->info.password);
 
@@ -170,16 +171,16 @@ GB_DESC CUserDesc[] =
 
 /***************************************************************************
 
-  .ConnectionUsers
+  .Connection.Users
 
 ***************************************************************************/
 
 #undef THIS
-#define THIS ((GB_SUBCOLLECTION)_object)
+#define THIS ((CSUBCOLLECTION *)_object)
 
 BEGIN_METHOD(CUSER_add, GB_STRING name; GB_STRING password; GB_BOOLEAN admin)
 
-  CCONNECTION *conn = GB.SubCollection.Container(THIS);
+  CCONNECTION *conn = GB_SubCollectionContainer(THIS);
   char *name = GB.ToZeroString(ARG(name));
   DB_USER info;
 
@@ -202,13 +203,14 @@ END_METHOD
 
 BEGIN_METHOD(CUSER_remove, GB_STRING name)
 
-  CCONNECTION *conn = GB.SubCollection.Container(THIS);
+  CCONNECTION *conn = GB_SubCollectionContainer(THIS);
   char *name = GB.ToZeroString(ARG(name));
 
+  GB_SubCollectionRemove(THIS, STRING(name), LENGTH(name));
+	
   if (check_user(conn, name, TRUE))
     return;
 
-  GB.SubCollection.Remove(THIS, STRING(name), LENGTH(name));
   conn->driver->User.Delete(&conn->db, name);
 
 END_METHOD
@@ -216,7 +218,7 @@ END_METHOD
 
 GB_DESC CConnectionUsersDesc[] =
 {
-  GB_DECLARE(".ConnectionUsers", 0), GB_INHERITS(".SubCollection"),
+  GB_DECLARE(".Connection.Users", 0), GB_INHERITS(".SubCollection"),
 
   GB_METHOD("Add", NULL, CUSER_add, "(Name)s[(Password)s(Admin)b]"),
   GB_METHOD("Remove", NULL, CUSER_remove, "(Name)s"),
