@@ -2,13 +2,11 @@
 
   sqlite.c
 
-  sqlite pseudo driver
-
-  (c) 2000-2007 Benoit Minisini <gambas@users.sourceforge.net>
+  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -18,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -101,15 +100,15 @@ static char *FindDatabase(char *name, char *hostName)
 	if (strcmp(basename(name), name))
 	{
 		if (IsDatabaseFile(name))
-			GB.NewString(&fullpath, name, 0);
+			fullpath = GB.NewZeroString(name);
 
 		return fullpath;
 	}
 
 	/* Hostname contains home area */
-	GB.NewString(&fullpath, hostName, 0);
-	GB.AddString(&fullpath, "/", 0);
-	GB.AddString(&fullpath, name, 0);
+	fullpath = GB.NewZeroString(hostName);
+	fullpath = GB.AddChar(fullpath, '/');
+	fullpath = GB.AddString(fullpath, name, 0);
 	if (IsDatabaseFile(fullpath))
 	{
 		return fullpath;
@@ -121,9 +120,9 @@ static char *FindDatabase(char *name, char *hostName)
 
 	if (dbhome != NULL)
 	{
-		GB.NewString(&fullpath, dbhome, 0);
-		GB.AddString(&fullpath, "/", 0);
-		GB.AddString(&fullpath, name, 0);
+		fullpath = GB.NewZeroString(dbhome);
+		fullpath = GB.AddChar(fullpath, '/');
+		fullpath = GB.AddString(fullpath, name, 0);
 
 		if (IsDatabaseFile(fullpath))
 		{
@@ -131,9 +130,9 @@ static char *FindDatabase(char *name, char *hostName)
 		}
 	}
 
-	GB.NewString(&fullpath, GB.GetTempDir(), 0);
-	GB.AddString(&fullpath, "/sqlite/", 0);
-	GB.AddString(&fullpath, name, 0);
+	fullpath = GB.NewZeroString(GB.TempDir());
+	fullpath = GB.AddString(fullpath, "/sqlite/", 0);
+	fullpath = GB.AddString(fullpath, name, 0);
 
 	if (IsDatabaseFile(fullpath))
 	{
@@ -144,26 +143,25 @@ static char *FindDatabase(char *name, char *hostName)
 	return NULL;
 }
 
-/*****************************************************************************
-
-  open_database()
-
-*****************************************************************************/
+//-------------------------------------------------------------------------
 
 static int open_database(DB_DESC *desc, DB_DATABASE * db)
 {
-	char *name = NULL;
+	char *host;
 	char *db_fullpath = NULL;
-	//bool memory = FALSE;
 	bool ver2 = FALSE;
 
 	if (!desc->name) // memory database
 		goto __SQLITE;
 
-	db_fullpath = FindDatabase(desc->name, desc->host);
+	host = desc->host;
+	if (!host)
+		host = "";
+
+	db_fullpath = FindDatabase(desc->name, host);
 	if (!db_fullpath)
 	{
-		GB.Error("Unable to locate database: &1", name);
+		GB.Error("Unable to locate database `&1` in `&2`", desc->name, host);
 		return TRUE;
 	}
 					 	
@@ -178,10 +176,10 @@ static int open_database(DB_DESC *desc, DB_DATABASE * db)
 	
 __SQLITE:
   
-  GB.LoadComponent("gb.db.sqlite3");
+  GB.Component.Load("gb.db.sqlite3");
   GB.Error(NULL);
 	
-	if (GB.ExistComponent("gb.db.sqlite3"))
+	if (GB.Component.Exist("gb.db.sqlite3"))
 		goto __SQLITE3;
 	else
 		goto __SQLITE2;
@@ -196,16 +194,23 @@ __SQLITE3:
 }
 
 
+//-------------------------------------------------------------------------
+
+static int database_is_system(DB_DATABASE * db, const char *name)
+{
+	return FALSE;
+}
+
 /*****************************************************************************
 
   The driver interface
 
 *****************************************************************************/
 
-DB_DRIVER DB_sqlite_pseudo_driver = 
+DB_DRIVER DB_sqlite_pseudo_driver =
 {
-	"sqlite",
-	open_database,
-	0
+	.name = "sqlite",
+	.Open = open_database,
+	.Database.IsSystem = database_is_system
 };
 
