@@ -1,14 +1,12 @@
 /***************************************************************************
 
-  list.h
+  gb_list.h
 
-  Linked lists management routines
-
-  (c) 2000-2007 Benoit Minisini <gambas@users.sourceforge.net>
+  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -18,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -36,7 +35,9 @@ typedef
 void LIST_insert(void *p_first, void *node, LIST *list);
 void LIST_remove(void *p_first, void *node, LIST *list);
 
-#define LIST_for_each(_var, _first) \
-  for(_var = (_first); _var; _var = (_var)->list.next)
+#define LIST_for_each_name(_var, _first, _name) \
+  for(_var = (_first); _var; _var = (_var)->_name.next)
 
+#define LIST_for_each(_var, _first) LIST_for_each_name(_var, _first, list)
+  
 #endif
