@@ -1,14 +1,12 @@
 /***************************************************************************
 
-  type_common.h
+  gb_type_common.h
 
-  Common datatypes definitions
-
-  (c) 2000-2007 Benoit Minisini <gambas@users.sourceforge.net>
+  (c) 2000-2017 Benoît Minisini <g4mba5@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 1, or (at your option)
+  the Free Software Foundation; either version 2, or (at your option)
   any later version.
 
   This program is distributed in the hope that it will be useful,
@@ -18,7 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+  MA 02110-1301, USA.
 
 ***************************************************************************/
 
@@ -41,6 +40,7 @@ enum {
   TF_PUBLIC      = 64,
   };
 
+#ifdef PROJECT_COMP
 
 enum {
   T_VOID         = 0,
@@ -54,25 +54,39 @@ enum {
   T_DATE         = 8,
   T_STRING       = 9,
   T_CSTRING      = 10,
-  T_VARIANT      = 11,
-  T_ARRAY        = 12,
+  T_POINTER      = 11,
+  T_VARIANT      = 12,
+  T_ARRAY        = 13,
+  T_STRUCT       = 14,
+  //T_NULL         = 15,
+  T_OBJECT       = 16
+  };
+
+#else
+
+enum {
+  T_VOID         = 0,
+  T_BOOLEAN      = 1,
+  T_BYTE         = 2,
+  T_SHORT        = 3,
+  T_INTEGER      = 4,
+  T_LONG         = 5,
+  T_SINGLE       = 6,
+  T_FLOAT        = 7,
+  T_DATE         = 8,
+  T_STRING       = 9,
+  T_CSTRING      = 10,
+  T_POINTER      = 11,
+  T_VARIANT      = 12,
   T_FUNCTION     = 13,
   T_CLASS        = 14,
   T_NULL         = 15,
   T_OBJECT       = 16,
-  T_POINTER      = T_INTEGER
-  };
   
-#define T_SIZEOF_BOOLEAN   1
-#define T_SIZEOF_BYTE      1
-#define T_SIZEOF_SHORT     2
-#define T_SIZEOF_INTEGER   4
-#define T_SIZEOF_LONG      8
-#define T_SIZEOF_SINGLE    4
-#define T_SIZEOF_FLOAT     8
-#define T_SIZEOF_DATE      8
-#define T_SIZEOF_STRING    4
-#define T_SIZEOF_VARIANT   12
-#define T_SIZEOF_OBJECT    4
+  TC_ARRAY       = 13,
+  TC_STRUCT      = 14
+  };
+
+#endif
 
 #endif
